%define dlname Botan

%define api     2
%define major   19
%define libname %mklibname botan %{api} %{major}
%define devname %mklibname botan %{api} -d

Name:           botan2
Version:        2.19.5
Release:        %mkrel 3
Summary:        Crypto and TLS for C++
Group:          System/Libraries
License:        BSD
URL:            https://botan.randombit.net/
Source0:        https://botan.randombit.net/releases/%{dlname}-%{version}.tar.xz#!/%{name}-%{version}.tar.xz

# Upstram patch to fix test failure
Patch0:         https://github.com/randombit/botan/pull/2837.patch
Patch1:         0001-Remove-usage-of-deprecated-asio-API-boost-1.87.patch
Patch2:         0001-Fix-compilation-on-GCC-15.patch

BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  boost-devel
BuildRequires:  trousers-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3dist(docutils)
BuildRequires:  python3dist(sphinx)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(sqlite3)

Requires:       python3

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library. This is the current stable release branch 2.x
of Botan.


%package -n     %{libname}
Summary:        Library files for %{name}
Group:          System/Libraries

%description -n %{libname}
The %{libname} package contains library files for %{name}.


%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
Documentation for %{name}.

This package contains HTML documentation for %{name}.


%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains the Python3 binding for %{name}.


%prep
%autosetup -p1 -n %{dlname}-%{version}

%py_shebang_fix \
configure.py \
src/scripts/*.py \
src/python/*.py

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules bzip2,zlib,boost,sqlite3,lzma,tpm

./configure.py \
        --distribution-info="%{_vendor} %{name} %{version}-%{release}" \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --docdir=%{_docdir} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --extra-cxxflags="%{build_cxxflags}" \
        --ldflags="%{build_ldflags}" \
        --enable-modules=%{enable_modules} \
        --with-python-versions=%{python3_version} \
        --with-sphinx \
        --enable-shared-library \
        --disable-static-library \
        --with-debug-info \
        --program-suffix=%{api} \
        --with-os-features=getrandom,getentropy

%make_build

%install
%make_install \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644"

chmod 755 %{buildroot}%{python3_sitearch}/%{name}.py

mv %{buildroot}%{_mandir}/man1/botan.1 %{buildroot}%{_mandir}/man1/botan%{api}.1

find %{buildroot} -name '*.a' -delete

%check
%ifnarch %arm %ix86
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./botan-test%{api}
%endif

%files
%license license.txt
%{_bindir}/botan%{api}
%{_mandir}/man1/botan%{api}.1.*

%files -n %{libname}
%license license.txt
%{_libdir}/libbotan-%{api}.so.%{major}{,.*}

%files -n %{devname}
%license license.txt
%{_includedir}/botan-%{api}/
%{_libdir}/libbotan-%{api}.so
%{_libdir}/pkgconfig/botan-%{api}.pc

%files doc
%license license.txt
%{_docdir}/botan-%{version}/

%files -n python3-%{name}
%license license.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/__pycache__/*


%changelog
* Thu Mar 06 2025 daviddavid <daviddavid> 2.19.5-3.mga10
+ Revision: 2161261
- rebuild for python 3.13

* Fri Feb 14 2025 daviddavid <daviddavid> 2.19.5-2.mga10
+ Revision: 2148744
- backport upstream patch to fix build with boost 1.87 and gcc 15

* Mon Jul 08 2024 kekepower <kekepower> 2.19.5-1.mga10
+ Revision: 2080403
- Update to version 2.19.5

* Fri Apr 12 2024 daviddavid <daviddavid> 2.19.4-4.mga10
+ Revision: 2056673
- re-enable botan cli using '--program-suffix=2' configure option

* Thu Apr 11 2024 daviddavid <daviddavid> 2.19.4-3.mga10
+ Revision: 2056599
- fix dependency on devel sub-pkg

* Thu Apr 11 2024 daviddavid <daviddavid> 2.19.4-2.mga10
+ Revision: 2056598
- drop/disable botan cli now in botan3
- enable tpm module
- fix/update some configure options

* Thu Feb 22 2024 kekepower <kekepower> 2.19.4-1.mga10
+ Revision: 2043091
- Update to version 2.19.4

* Tue Dec 19 2023 papoteur <papoteur> 2.19.3-2.mga10
+ Revision: 2019197
- Mass Rebuild - Python 3.12

* Thu Nov 17 2022 kekepower <kekepower> 2.19.3-1.mga9
+ Revision: 1908513
- Update to version 2.19.3

* Wed Jul 06 2022 wally <wally> 2.19.2-2.mga9
+ Revision: 1867843
- disable tests on i586 for now as they're timeouting on BS
- disable instructions we don't support on i586
- build using our build time flags
- simplify python shebang fix
- rebuild for boost 1.79.0

* Mon Jun 06 2022 kekepower <kekepower> 2.19.2-1.mga9
+ Revision: 1861361
- Update to version 2.19.2

* Thu Mar 31 2022 umeabot <umeabot> 2.19.1-2.mga9
+ Revision: 1837212
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 2.19.1-1.mga9
+ Revision: 1775134
- major version 19
- version 2.19.1
- rebuild for python-3.10

* Sun Dec 19 2021 wally <wally> 2.18.2-2.mga9
+ Revision: 1762677
- rebuild for boost 1.78.0

* Fri Oct 29 2021 kekepower <kekepower> 2.18.2-1.mga9
+ Revision: 1753245
- Add upstram patch to fix test failure
- Update to version 2.18.2
+ wally <wally>
- rebuild for openssl 3.0.0

* Thu Sep 09 2021 wally <wally> 2.18.1-2.mga9
+ Revision: 1744695
- rebuild for boost 1.77.0

* Thu May 20 2021 kekepower <kekepower> 2.18.1-1.mga9
+ Revision: 1725878
- Update to version 2.18.1

* Fri May 14 2021 wally <wally> 2.18.0-2.mga9
+ Revision: 1722941
- rebuild for boost 1.76.0

* Fri Apr 16 2021 kekepower <kekepower> 2.18.0-1.mga9
+ Revision: 1715976
- Update to version 2.18.0

* Sat Mar 20 2021 daviddavid <daviddavid> 2.17.3-3.mga9
+ Revision: 1705922
- rebuild for python 3.9

* Thu Dec 31 2020 wally <wally> 2.17.3-2.mga8
+ Revision: 1666739
- rebuild for boost 1.75.0

* Tue Dec 22 2020 kekepower <kekepower> 2.17.3-1.mga8
+ Revision: 1662697
- Update to version 2.17.3

* Sun Dec 20 2020 wally <wally> 2.17.2-2.mga8
+ Revision: 1661981
- rebuild for boost 1.74.0

* Sat Nov 14 2020 kekepower <kekepower> 2.17.2-1.mga8
+ Revision: 1645616
- Update to version 2.17.2

* Sun Nov 08 2020 kekepower <kekepower> 2.17.1-1.mga8
+ Revision: 1643665
- Update to version 2.17.1

* Thu Nov 05 2020 kekepower <kekepower> 2.17.0-1.mga8
+ Revision: 1642949
- Update to version 2.17.0

* Thu Oct 22 2020 daviddavid <daviddavid> 2.16.0-1.mga8
+ Revision: 1638525
- new version: 2.16.0
- now libmajor is 16

* Fri Jul 17 2020 daviddavid <daviddavid> 2.15.0-1.mga8
+ Revision: 1606718
- new version: 2.15.0
- now libmajor is 15

* Sun May 03 2020 wally <wally> 2.14.0-2.mga8
+ Revision: 1578035
- rebuild for boost 1.73.0

* Tue Apr 07 2020 kekepower <kekepower> 2.14.0-1.mga8
+ Revision: 1565474
- Update to version 2.14.0
- Enable extra modules - boost,sqlite3,lzma

* Wed Feb 19 2020 umeabot <umeabot> 2.13.0-3.mga8
+ Revision: 1542957
- Mageia 8 Mass Rebuild

* Wed Jan 08 2020 daviddavid <daviddavid> 2.13.0-2.mga8
+ Revision: 1477272
- disable testsuite on arm

* Wed Jan 08 2020 daviddavid <daviddavid> 2.13.0-1.mga8
+ Revision: 1477262
- new version: 2.13.0
- now libmajor is 13

* Thu Dec 05 2019 daviddavid <daviddavid> 2.12.1-1.mga8
+ Revision: 1464532
- new version: 2.12.1
- now libmajor is 12

* Fri Sep 20 2019 daviddavid <daviddavid> 2.11.0-3.mga8
+ Revision: 1444031
- rebuild for python3.8

* Sat Aug 17 2019 wally <wally> 2.11.0-2.mga8
+ Revision: 1429491
- drop python2-sphinx BR

* Mon Jul 15 2019 daviddavid <daviddavid> 2.11.0-1.mga8
+ Revision: 1421532
- new version: 2.11.0
- now libmajor is 11

* Thu Jul 04 2019 wally <wally> 2.10.0-2.mga8
+ Revision: 1418497
- loosen lib requires

* Sun Jun 30 2019 daviddavid <daviddavid> 2.10.0-1.mga8
+ Revision: 1416326
- new version: 2.10.0
- now libmajor is 10

* Mon Jan 07 2019 kekepower <kekepower> 2.9.0-2.mga7
+ Revision: 1351021
- Rebuild for Python 3.7

* Sat Jan 05 2019 kekepower <kekepower> 2.9.0-1.mga7
+ Revision: 1349281
- Update to version 2.9.0

* Sun Oct 28 2018 daviddavid <daviddavid> 2.8.0-2.mga7
+ Revision: 1326405
- add some missing Group
- fix some description and summary
- fix some Conflicts, Obsoletes, Provides
+ kekepower <kekepower>
- Requires appropriate sub packages

* Sun Oct 28 2018 kekepower <kekepower> 2.8.0-1.mga7
+ Revision: 1326389
- Update to version 2.8.0
- Create proper sub pacakges for dev and libs

* Fri Sep 21 2018 umeabot <umeabot> 2.6.0-5.mga7
+ Revision: 1295632
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 2.6.0-4.mga7
+ Revision: 1248827
- add back pycache

* Fri Jul 06 2018 daviddavid <daviddavid> 2.6.0-3.mga7
+ Revision: 1242164
- update files list (no more __pycache__ reference)

* Fri May 25 2018 shlomif <shlomif> 2.6.0-2.mga7
+ Revision: 1232167
- fix owned dirs as reported by youri
- New version 2.6.0
+ kekepower <kekepower>
- imported package botan2

